#!/bin/sh
INSTALLDIR="/Users/stuart/GRID2"
HOSTNAME="iona"
# end of local installation parameters
PROJECT="biosphere01"
SOURCEDIR=$PWD
CATALINA_HOME="$INSTALLDIR/apache-tomcat-5.5.26"
export CATALINA_HOME="$CATALINA_HOME"
export ANT_HOME="/Developer/Java/Ant"
echo "Installation script for $PROJECT - installing tomcat, GridSphere, OGSA-DAI and eXist"
echo "Note: this script should be run from the source directory: $SOURCEDIR"
echo "Installation directory: $INSTALLDIR"
echo "CATALINA_HOME=$CATALINA_HOME"
date
if [ -d $INSTALLDIR ]
then 
    echo "WARNING: $INSTALLDIR exists - contents will be overwritten"
else
    mkdir $INSTALLDIR
    echo "$INSTALLDIR created"
fi
echo ">> checking contents of distribution in $SOURCEDIR"
for x in "apache-tomcat-5.5.26.zip" "dojo-release-1.1.0.tar" "exist-1.2.0-rev7233.war" "gridsphere-3.1-src.tar" "ogsadai-3.0-axis-1.4-src.zip"  
do
    if [ -f "./sources/$x" ]
    then 
	echo "CHECK: ./sources/$x exists"
	mv "./sources/$x" "$INSTALLDIR/."
    else
	echo "ERROR: ./sources/$x missing"
    fi
done
for x in "$PROJECT.tar" "tomcat-users.xml" "spring-tomcat-weaver.jar" "war-context.xml"  "exist.jar" "xmldb.jar" "xmlrpc-1.2-patched.jar"
do
    if [ -f $x ]
    then 
	echo "CHECK: $x exists"
    else
	echo "ERROR: $x missing"
    fi
done
cd $INSTALLDIR
unzip -qq apache-tomcat-5.5.26.zip
tar -xf gridsphere-3.1-src.tar
unzip -qq ogsadai-3.0-axis-1.4-src.zip
tar -xf dojo-release-1.1.0.tar
mkdir sources
mv *.tar ./sources/.
mv *.zip ./sources/.
echo ">>tomcat install and config"
cd $SOURCEDIR
chmod u+x "$CATALINA_HOME/bin/startup.sh"
chmod u+x "$CATALINA_HOME/bin/shutdown.sh"
chmod u+x "$CATALINA_HOME/bin/catalina.sh"
chmod u+x "$CATALINA_HOME/bin/setclasspath.sh"
cp tomcat-users.xml "$CATALINA_HOME/conf/tomcat-users.xml"
cp spring-tomcat-weaver.jar "$CATALINA_HOME/server/lib/spring-tomcat-weaver.jar"
echo "--tomcat install and config - done"
echo ">>deploy exist war file"
cd $INSTALLDIR
cp exist-1.2.0-rev7233.war "$CATALINA_HOME/webapps/exist.war"
mv exist-1.2.0-rev7233.war ./sources/.
echo ">>> TODO: manually configure eXist examples via web interface"
echo ">>gridsphere install and config"
if [ -d "$HOME/.gridsphere" ]
then
    mv "$HOME/.gridsphere" "$HOME/.gridsphere-bak"
    echo "**** existing ~/.gridsphere directory moved to .gridsphere-bak"
fi
cd $INSTALLDIR
cd gridsphere-3.1
ant compile
ant install
echo ">> dojo install"
cd $INSTALLDIR
mv dojo-release-1.1.0 "$CATALINA_HOME/webapps/gridsphere/javascript/dojo"
echo ">>>TODO: manually configure GridSphere user database via web interface"
echo "--gridsphere install and config - done"
echo ">> $PROJECT installation"
cd $INSTALLDIR
cd gridsphere-3.1
cp "$SOURCEDIR/$PROJECT.tar" .
tar -xf "$PROJECT.tar"
cd "./projects/$PROJECT"
ant compile
ant deploy
echo ">patch deployed jar"
cd ./build/lib/
jar -uf "$PROJECT.jar" client-config.wsdd 
cp "$PROJECT.jar" "$CATALINA_HOME/webapps/biosphere01/WEB-INF/lib/."
echo ">> $PROJECT installation - done"
echo ">>ogsadai build and config"
cd $INSTALLDIR
cd ogsadai-3.0-axis-1.4-src
ant
cd $SOURCEDIR
cp war-context.xml "$INSTALLDIR/ogsadai-3.0-axis-1.4-src/build/ogsadai-3.0-axis-1.4-bin/deploy/war-context.xml"
cd $CATALINA_HOME
./bin/startup.sh
echo "**********tomcat running for OGSA-DAI deployment****************"
cd "$INSTALLDIR/ogsadai-3.0-axis-1.4-src/build/ogsadai-3.0-axis-1.4-bin"
echo ">>first  buildDeployWARAndServices usually fails...."
ant -Dtomcat.dir=$CATALINA_HOME -Ddai.host=$HOSTNAME.local -Ddai.port=8080 buildDeployWARAndServices
echo ">>second deployWARAndServices should succeed"
ant -Dtomcat.dir=$CATALINA_HOME -Ddai.host=$HOSTNAME.local -Ddai.port=8080 deployWARAndServices
echo "--ogsadai install and config - done"
echo ">>ogsadai - exist install and config"
cd $SOURCEDIR
echo ">>create OGSA-DAI XML DB resource"
mkdir "$INSTALLDIR/exist"
mkdir "$INSTALLDIR/exist/resources"
cp exist.jar "$INSTALLDIR/exist/resources/exist.jar"
cp xmldb.jar "$INSTALLDIR/exist/resources/xmldb.jar"
cp xmlrpc-1.2-patched.jar "$INSTALLDIR/exist/resources/xmlrpc-1.2-patched.jar"
cd "$INSTALLDIR/ogsadai-3.0-axis-1.4-src/build/ogsadai-3.0-axis-1.4-bin"
ant -Ddai.db.product=eXist -Ddai.db.vendor=eXist -Ddai.db.version=1.2.0  -Ddai.db.uri=xmldb:exist://localhost:8080/exist/xmlrpc/db  -Ddai.db.driver=org.exist.xmldb.DatabaseImpl  -Ddai.resource.id=ExistDataResource createXMLDBConfig
cp ExistDataResource  "$INSTALLDIR/exist/ExistDataResource"
ant -Dtomcat.dir="$CATALINA_HOME"  -Ddai.resource.jar.dir="$INSTALLDIR/exist/resources"  -Ddai.resource.file="$INSTALLDIR/exist/ExistDataResource" deployResource
ant -Dtomcat.dir="$CATALINA_HOME"  -Ddai.resource.id=ExistDataResource  -Ddai.user=guest -Ddai.password=guest permit
ant -Dtomcat.dir="$CATALINA_HOME" -Ddai.host=$HOSTNAME.local -Ddai.port=8080 deployWARAndServices
echo "--ogsadai - exist install and config - done"
echo "----all done >>> complete eXist (example database) and GridSphere (user database) installation manually ----"
date
echo "** tomcat is running **"
echo "CATALINA_HOME=$CATALINA_HOME"
