// Copyright (c) The University of Edinburgh,  2008.

package org.biosphere.portlets.util;

import java.io.BufferedReader;
import java.io.Reader;
import java.net.URL;
import java.util.Hashtable;
import java.util.List;
import java.util.Map;
import java.util.Vector;
import java.util.StringTokenizer;
//ogsadai-3.0-client.jar
import uk.org.ogsadai.client.toolkit.DataIterator;
import uk.org.ogsadai.client.toolkit.DataRequestExecutionResource;
import uk.org.ogsadai.client.toolkit.PipelineWorkflow;
import uk.org.ogsadai.client.toolkit.RequestExecutionType;
import uk.org.ogsadai.client.toolkit.RequestResource;
import uk.org.ogsadai.client.toolkit.ServerProxy;
import uk.org.ogsadai.client.toolkit.activities.delivery.DeliverToRequestStatus;
import uk.org.ogsadai.client.toolkit.activities.xmldb.XMLListCollections;
import uk.org.ogsadai.client.toolkit.activities.xmldb.XMLListResources;
import uk.org.ogsadai.client.toolkit.activities.xmldb.XPathQuery;
// import the base class for the example
import uk.org.ogsadai.client.toolkit.example.ClientBase;

// ogsadai-3.0-clientserver.jar 
import uk.org.ogsadai.resource.ResourceID;
import uk.org.ogsadai.resource.request.RequestStatus;

/**
 * Simple interface utility to XML DB via OGSA-DAI based on the XMDBClient example.
 * stuart@aiai.ed.ac.uk  28/4/2008
 *
 * @author Stuart Aitken
 */ 
public class XMLDBCollectionListingUtil extends ClientBase {

    private static final String DATA_RESOURCE = "d";

    /** List collections command. */
    private static final String LIST_COLLECTIONS = "listCollections";
    /** List resources command. */
    private static final String LIST_RESOURCES = "listResources";

    private static StringBuffer config;
    private static StringBuffer report;
    private static XMLListCollections result;

 
    public XMLDBCollectionListingUtil()
    {
	this.config = new StringBuffer();
	this.report = new StringBuffer();
	this.result = null;
    }

    /**
     * Parse the arguments, submit a request to the OGSA-DAI server
     * and pretty-print the results.
     * 
     * @param args 
     *     Command-line arguments.
     *     
     * @throws Exception if an error occurs.
     */
    public boolean execute(String url, String collection) throws Exception {
	System.out.println("XMLDBCollList:"+url+" "+collection);
        if(url == null)  {
            url = "http://localhost:8080/dai/services/";
        }
	String drerIDStr = "DataRequestExecutionResource";
        ResourceID drerID = new ResourceID(drerIDStr);
	String dataResourceIDStr = "ExistDataResource";
        ResourceID dataResourceID = new ResourceID(dataResourceIDStr);
	String command = LIST_COLLECTIONS;

	this.config.append("DRER ID: " + drerID);
	this.config.append("\nData Resource ID: " + dataResourceID);
        this.config.append("\nBase Services URL: " + url);
        this.config.append("\nCommand: " + command);
        if (collection != null)
        {
            this.config.append("\nCollection: " + collection);
        }

       
        // Get server.
        ServerProxy server = new ServerProxy();
        server.setDefaultBaseServicesURL(new URL(url));

        // Get DRER
        DataRequestExecutionResource drer = 
            server.getDataRequestExecutionResource(drerID);

	return listCollections(drer, dataResourceID, collection);
    }

    /**
     * Submit a request to a DRER to list the collections of
     * an XMLDB data resource.
     *
     * @param drer
     *      Client toolkit data request execution resource proxy.
     * @param dataResourceID
     *      ID of XMLDB data resource.
     * @param collection
     *      Sub-collection of XMLDB data resource whose collections are
     *      to be listed. If <code>null</code> then the the collections
     *      of the XMLDB data resource base collection are listed.
     * @throws Exception
     *     If there are any problems.
     */
    private  boolean listCollections(DataRequestExecutionResource drer,
                                        ResourceID dataResourceID,
                                        String collection)
        throws Exception
    {
        // List collections.
        XMLListCollections listCollections = new XMLListCollections();
        listCollections.setResourceID(dataResourceID);
        if (collection != null)
        {
            listCollections.addParentCollection(collection);
        }
        // Deliver to request status.
        DeliverToRequestStatus deliverToRequestStatus = 
            new DeliverToRequestStatus();
        deliverToRequestStatus.connectInput(listCollections.getDataOutput());

        // Workflow.
        PipelineWorkflow pipeline = new PipelineWorkflow();
        pipeline.add(listCollections);
        pipeline.add(deliverToRequestStatus);

        // Execute.
        RequestResource requestResource = null;
        try
        {
            requestResource = 
                drer.execute(pipeline, RequestExecutionType.SYNCHRONOUS);
        }
        catch (Throwable e)
        {
            this.report.append("A problem has occured...listCollections()");
            while (e != null)
            {
                this.report.append(e.getMessage());
                e = e.getCause();
            }
            return false; 
        }
        RequestStatus status = requestResource.getRequestStatus();
        // Get request execution status.
        this.report.append(status.getExecutionStatus());

	this.result = listCollections;
	/* to get results 
        while (listCollections.hasNextData())
        {
            DataIterator iterator = listCollections.nextData();
            while (iterator.hasNext())
            {
                <-(iterator.next());
            }
        }
	*/
	return true;
    }
    public String getConfig() {
	return this.config.toString();
    }
    public String getReport() {
	return this.report.toString();
    }
    public XMLListCollections getResults() {
	return this.result;
    }


}
